//
//  CaregiversListView.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 11/18/23.
//
import SwiftUI

struct Caregiver: Identifiable {
    let id: UUID
    var name: String
    var email: String
    var phone: String
}

struct CaregiversListView: View {
    @State private var caregivers: [Caregiver] = [
        Caregiver(id: UUID(), name: "Beatriz", email: "Bea@example.com", phone: "555-1234"),
        Caregiver(id: UUID(), name: "Mom", email: "mom@example.com", phone: "555-5678")
    ]

    @State private var isEditing = false
    @State private var showingAddSheet = false
    @State private var selectedCaregiver: Caregiver?

    var body: some View {
            NavigationView {
                List {
                    ForEach(caregivers) { caregiver in
                        NavigationLink(destination: CaregiverDetailView(caregiver: $caregivers[getIndex(for: caregiver)])) {
                            CaregiverRowView(caregiver: caregiver)
                        }
                    }
                    .onDelete(perform: deleteCaregiver)
                }
                .listStyle(PlainListStyle())
                .navigationTitle("Pet Sitters")
                .navigationBarItems(
                    leading: EditButton(),
                    trailing: Button(action: {
                        showingAddSheet.toggle()
                    }) {
                        Image(systemName: "plus.circle.fill")
                            .font(.largeTitle)
                            .foregroundColor(CustomColor.myColor)
                    }
                )
                .sheet(isPresented: $showingAddSheet) {
                    AddCaregiverView(caregivers: $caregivers)
                }
            }
            .tint(CustomColor.myColor)

    }

    private func deleteCaregiver(at offsets: IndexSet) {
        caregivers.remove(atOffsets: offsets)
    }

    private func getIndex(for caregiver: Caregiver) -> Int {
        if let index = caregivers.firstIndex(where: { $0.id == caregiver.id }) {
            return index
        }
        return 0
    }
}

struct CaregiverRowView: View {
    var caregiver: Caregiver

    var body: some View {
        VStack(alignment: .leading) {
            Text(caregiver.name)
                .font(.headline)
            Text(caregiver.email)
                .foregroundColor(.secondary)
        }
    }
}

struct CaregiverDetailView: View {
    @Binding var caregiver: Caregiver

    var body: some View {
        Form {
            Section(header: Text("Sitter Info")) {
                TextField("Name", text: $caregiver.name)
                TextField("Email", text: $caregiver.email)
                TextField("Phone", text: $caregiver.phone)
            }
        }
        .navigationBarTitle("Edit Sitter")
        .tint(CustomColor.myColor)
    }
}

struct AddCaregiverView: View {
    @State private var newCaregiver = Caregiver(id: UUID(), name: "", email: "", phone: "")
    @Binding var caregivers: [Caregiver]

    var body: some View {
        NavigationView {
            Form {
                Section(header: Text("Sitter Info")) {
                    TextField("Name", text: $newCaregiver.name)
                    TextField("Email", text: $newCaregiver.email)
                    TextField("Phone", text: $newCaregiver.phone)
                }
            }
            .navigationBarTitle("Add Sitter", displayMode: .inline)
            .navigationBarItems(
                trailing: Button(action: {
                    caregivers.append(newCaregiver)
                }) {
                    Text("Save")
                }
                .disabled(newCaregiver.name.isEmpty || newCaregiver.email.isEmpty || newCaregiver.phone.isEmpty)
            )
            
        }
    }
}

struct CaregiversListView_Previews: PreviewProvider {
    static var previews: some View {
        CaregiversListView()
    }
}








