//
//  ChatView.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 9/30/23.
//

import SwiftUI

struct ChatView: View {
    @State var index = 0
    @State var expand = false
    var body: some View {
        ZStack{
            VStack{
                ZStack{
                    Chats(expand: self.$expand).opacity(self.index == 0 ? 1 : 0)
                }
                .background(Color.gray)
            }
        }
        .background(Color.gray)
        .edgesIgnoringSafeArea(.all)
    }
}
struct Chats : View {

    @Binding var expand : Bool
    
    var body : some View{

        VStack(spacing: 0){
            TopView(expand: self.$expand).zIndex(25)
            
            Centerview(expand: self.$expand).offset(y: -25)
        }
        .background(Color.gray)
    }
}
struct TopView : View {
    
    @State var search = ""
    @Binding var expand : Bool
    
    var body : some View{
        VStack(spacing: 22){
            if self.expand {
                ScrollView(.horizontal, showsIndicators: false) {
                    HStack(spacing: 18){
                        Button(action: {
                        }) {
                            Image(systemName: "plus")
                                .resizable()
                                .frame(width: 25, height: 25)
                                .foregroundColor(Color(.white))
                                .padding(18)
                        }
                        .background(Color(.white).opacity(0.5))
                        .clipShape(Circle())
                        
                        ForEach(data) { item in
                            Button(action: {
                            }) {
                                Image(item.img)
                                    .resizable()
                                    .scaledToFit()
                                    .frame(width: 60, height: 60)
                                    .shadow(radius: 2)
                                    .background(Color(.white))
                                    .clipShape(Circle())
                            }
                        }
                        .padding(.leading)
                    }
                    .padding(.top, 60.0)
                }
            }
            
            HStack(spacing: 15){
                Image(systemName: "magnifyingglass")
                    .resizable()
                    .frame(width: 18, height: 18)
                    .foregroundColor(Color.black.opacity(0.3))
                TextField("Search", text: self.$search)
            }
            .padding()
            .background(Color.white)
            .cornerRadius(8)
            .padding(.bottom, 10)
        }
        .padding()
        .padding(.top)
        .background(CustomColor.myColor)
    }
}

struct Centerview : View {
    @Binding var expand : Bool
    var body : some View{
        List(data){i in
            if i.id == 0{
                cellView(data : i)
                .onAppear {
                    self.expand = true
                }
                .onDisappear {
                    self.expand = false
                }
            }
            else{
                cellView(data : i)
            }
        }
        .padding(.top, 20)
        .background(Color.white)
    }
}
struct cellView : View {
    var data : Msg
    var body : some View{
        HStack(spacing: 12){
            Image(data.img)
            .resizable()
            .frame(width: 55, height: 55)
            VStack(alignment: .leading, spacing: 12) {
                Text(data.name)
                Text(data.msg).font(.caption)
            }
            Spacer(minLength: 0)
            VStack{
                Text(data.date)
                Spacer()
            }
        }.padding(.vertical)
    }
}
struct Msg : Identifiable {
    var id : Int
    var name : String
    var msg : String
    var date : String
    var img : String
}

var data = [
    Msg(id: 0, name: "Sarah", msg: "We went for a walk around the block after lunch an...", date: "9/10/23",img: "User2"),
    Msg(id: 1, name: "Dad", msg: "Awesome! :)", date: "9/03/23",img: "User1"),
    Msg(id: 2, name: "Mom", msg: "Our flight gets in at 11:40ish and then we will head ove...", date: "7/08/23",img: "User4"),
    Msg(id: 4, name: "Bea", msg: "His pills are on the counter!", date: "1/01/23",img: "User3"),
    ]

struct ChatView_Previews: PreviewProvider {
    static var previews: some View {
        ChatView()
    }
}
