//
//  CaregiverHomeView.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 9/30/23.
//

import SwiftUI
import Popovers


struct CaregiverHomeView: View {
    @State private var showAlert = false

    
    var body: some View {
        NavigationView {
            VStack(alignment: .center, spacing: 16) {
                TopBarView()
                ScrollView {
                    VStack {
                        HStack{
                            Text("Hello, Pet Sitter!")
                                .font(.custom("Poppins-Bold", size: 30))
                                .multilineTextAlignment(.leading)
                                .padding()
                            Spacer()
                        }
                        ZStack {
                            Image("Burnley1")
                                .resizable()
                                .aspectRatio(contentMode: .fill)
                                .padding(.top, 150.0)
                                .frame(minWidth: 0, maxWidth: .infinity)
                                .frame(height: 220)
                                .ignoresSafeArea()
                                .clipShape(RoundedRectangle(cornerRadius: 10))
                                .shadow(radius: 2)
                            
                            NavigationLink(destination: PetOne()) {
                                ZStack {
                                    RoundedRectangle(cornerRadius: 4)
                                        .fill(Color.white)
                                        .frame(width: 140.0, height: 30)
                                        .shadow(radius: 1)
                                    HStack {
                                        Text("Burnley")
                                            .font(.custom("Inter", size: 17))
                                            .fontWeight(.bold)
                                            .foregroundColor(Color.black)
                                        Image(systemName: "chevron.right")
                                            .font(.custom("Inter", size: 17)) .foregroundColor(CustomColor.myColor)
                                    }
                                }
                            }
                            .offset(x: 80, y: 85)
                        }
                        .padding(.horizontal)
                        Divider()
                            .padding(.all)
                        ZStack {
                            RoundedRectangle(cornerRadius: 10)
                                .fill(Color.gray.opacity(0.1))
                                .frame(height: 180)
                                .shadow(radius: 2)
                            ZStack {
                                RoundedRectangle(cornerRadius: 4)
                                    .fill(.white)
                                    .frame(width: 150.0, height: 35)
                                RoundedRectangle(cornerRadius: 4)
                                    .fill(CustomColor.myColor)
                                    .frame(width: 140.0, height: 26)
                                    .shadow(radius: 1)
                                Text("Quick Actions")
                                    .font(.subheadline)
                                    .fontWeight(.bold)
                                    .foregroundColor(Color.white)
                            }
                                .offset(x: -100, y: -86)
                        HStack(spacing: 20) {
                            NavigationLink(destination: CalendarView()){
                                VStack(spacing: 10) {
                                    Image("Calendar")
                                        .resizable()
                                        .scaledToFit()
                                        .frame(width:50, height: 50)
                                    
                                    Text("Schedule")
                                        .font(.caption)
                                        .foregroundColor(.black)
                                        .multilineTextAlignment(.center)
                                }
                                .frame(width: 140, height: 120)
                                .background(Color.white)
                                .cornerRadius(10)
                                .shadow(radius: 3)
                            }
                            VStack(spacing: 10) {
                                Image("SOS")
                                    .resizable()
                                    .scaledToFit()
                                    .frame(width: 50, height: 50)
                                
                                Text("Emergency")
                                    .font(.caption)
                                    .foregroundColor(.black)
                                    .multilineTextAlignment(.center)
                            }
                            .frame(width: 140, height: 120)
                            .background(Color.white)
                            .cornerRadius(10)
                            .shadow(radius: 3)
                            .onTapGesture {
                                showAlert = true
                            }
                            
                            .alert(isPresented: $showAlert) {
                                Alert(
                                    title: Text("Emergency Call"),
                                    message: Text("Are you sure you want to call the emergency vet?"),
                                    primaryButton: .destructive(
                                        Text("Call"),
                                        action: {
                                            
                                        }
                                    ),
                                    secondaryButton: .cancel()
                                )
                            }
                            
                        }
                        .padding([.top, .leading, .trailing])
                    }
                        .padding(.all)
                        Divider()
                            .padding(.all)
                        ZStack{
                            ToDoListView()
                            Text("To Do:")
                                .font(.custom("Poppins-Bold", size: 28))
                                .multilineTextAlignment(.leading)
                                .offset(x: -120, y: -170)
                        }
                    }
                    .padding(.horizontal)
                }
            }
        }
        .navigationBarHidden(true)
        .tint(CustomColor.myColor)
    }
}
struct CaregiverHomeView_Previews: PreviewProvider {
    static var previews: some View {
        CaregiverHomeView()
    }
}



