//
//  PetParentHomeView.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 10/8/23.
//

import SwiftUI

struct PetParentHomeView: View {
    var body: some View {
        NavigationView {
            VStack(alignment: .center, spacing: 16) {
                TopBarView()
                ScrollView {
                    VStack {
                        HStack {
                            Text("Hello, human!")
                                .font(.custom("Poppins-Bold", size: 30))
                                .multilineTextAlignment(.leading)
                                .padding([.top, .leading])
                            Spacer()
                        }
                        ZStack {
                            RoundedRectangle(cornerRadius: 10)
                                .fill(Color.gray.opacity(0.1))
                                .frame(height: 160)
                                .shadow(radius: 2)
                            ZStack {
                                RoundedRectangle(cornerRadius: 4)
                                    .fill(.white)
                                    .frame(width: 150.0, height: 35)
                                RoundedRectangle(cornerRadius: 4)
                                    .fill(CustomColor.myColor)
                                    .frame(width: 140.0, height: 26)
                                    .shadow(radius: 1)
                                Text("Quick Actions")
                                    .font(.subheadline)
                                    .fontWeight(.bold)
                                    .foregroundColor(Color.white)
                            }
                                .offset(x: -100, y: -76)
                    HStack(spacing: 20) {
                        NavigationLink(destination: PetProfilesView()) {
                            VStack {
                                Image("PetParent")
                                    .resizable()
                                    .scaledToFit()
                                    .frame(width:40, height: 40)
                                Text("My Pets")
                                    .font(.caption)
                                    .foregroundColor(.black)
                                    .multilineTextAlignment(.center)
                            }
                            .frame(width: 95, height: 95)
                            .background(Color.white)
                            .cornerRadius(10)
                            .shadow(radius: 3)
                        }
                        NavigationLink(destination: CalendarView()) {
                            VStack {
                                Image("Calendar")
                                    .resizable()
                                    .scaledToFit()
                                    .frame(width:40, height: 40)
                                Text("Calendar")
                                    .font(.caption)
                                    .foregroundColor(.black)
                                    .multilineTextAlignment(.center)
                            }
                            .frame(width: 95, height: 95)
                            .background(Color.white)
                            .cornerRadius(10)
                            .shadow(radius: 3)
                        }
                        NavigationLink(destination: LocationTrackingView()) {
                            VStack {
                                Image("Location")
                                    .resizable()
                                    .scaledToFit()
                                    .frame(width:40, height: 40)
                                Text("Pet Locations")
                                    .font(.caption)
                                    .foregroundColor(.black)
                                    .multilineTextAlignment(.center)
                            }
                            .frame(width: 95, height: 95)
                            .background(Color.white)
                            .cornerRadius(10)
                            .shadow(radius: 3)
                        }
                            }
                    .padding([.top, .leading, .trailing])
                            
                        }
                        .padding([.top, .leading, .trailing])
                        
                        Divider()
                            .padding(.horizontal, 30)
                            .padding(.vertical)
                        
                        VStack {
                            Text("Today's updates")
                                .font(.custom("Poppins-Bold", size: 20))
                                .multilineTextAlignment(.leading)
                                .padding(.trailing, 160)
                            HStack {
                                Image("User2")
                                    .resizable()
                                    .aspectRatio(contentMode: .fill)
                                    .frame(width: 40, height: 40)
                                    .clipShape(Circle())
                                
                                Text("Beatriz")
                                    .font(.headline)
                                    .foregroundColor(.black)
                                
                                Spacer()
                                
                                Image(systemName: "ellipsis")
                                
                            }
                            .padding(.horizontal, 25)
                        }
                        
                        Image("Burnley1")
                            .resizable()
                            .aspectRatio(contentMode: .fill)
                            .frame(maxHeight: 300)
                            .clipped()
                            .padding(.horizontal, 25)
                        
                        HStack(spacing: 24) {
                            LikeButtonView()
                            NavigationLink(destination: CommentView()) {
                                HStack(spacing: 8) {
                                    Image(systemName: "message")
                                        .foregroundColor(CustomColor.myColor)
                                    Text("Comment")
                                        .font(.custom("Inter", size: 14))
                                        .fontWeight(.regular)
                                        .foregroundColor(.black)
                                }
                            }
                            Spacer()
                            Image(systemName: "bookmark")
                        }
                        .padding(.horizontal, 25)
                        Spacer()
                        
                        HStack {
                            Text("Porch hangs! Enjoying the weather today!")
                                .font(.caption)
                                .foregroundColor(.black)
                            
                            Text("2 hours ago")
                                .font(.footnote)
                                .foregroundColor(.gray)
                            Spacer()
                        }
                        .padding(.horizontal, 25)
                        
                        Divider()
                            .padding(.horizontal, 30)
                            .padding(.vertical)
                        
                        ZStack{
                            ToDoListView()
                            Text("To Do:")
                                .font(.custom("Poppins-Bold", size: 28))
                                .multilineTextAlignment(.leading)
                                .offset(x: -120, y: -170)
                        }
                    }
                }
            }
            .tint(CustomColor.myColor)
        }
        .navigationBarHidden(true)
        .tint(CustomColor.myColor)
    }
}
struct PetParentHomeView_Previews: PreviewProvider {
    static var previews: some View {
        PetParentHomeView()
    }
}
