//
//  LocationViewModel.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 11/5/23.
//
import Foundation
import CoreLocation
import Combine

class LocationViewModel: NSObject, ObservableObject, CLLocationManagerDelegate {
    private var locationManager = CLLocationManager()
    @Published var userLocationCoordinate: CLLocationCoordinate2D?
    @Published var pets: [Pet] = []
    
    override init() {
        super.init()
        self.locationManager.delegate = self
        self.locationManager.desiredAccuracy = kCLLocationAccuracyNearestTenMeters
    }

    func startUpdatingLocation() {
        locationManager.requestWhenInUseAuthorization()
        locationManager.startUpdatingLocation()
    }

    func stopUpdatingLocation() {
        locationManager.stopUpdatingLocation()
    }

    func updatePetLocation(pet: Pet, newLocation: CLLocationCoordinate2D) {
        if let index = pets.firstIndex(where: { $0.id == pet.id }) {
            pets[index].location = newLocation
        }
    }

    func locationManager(_ manager: CLLocationManager, didUpdateLocations locations: [CLLocation]) {
        if let location = locations.last {
            userLocationCoordinate = location.coordinate
            for pet in pets {
                if let petLocation = pet.location {
                    updatePetLocation(pet: pet, newLocation: location.coordinate)
                }
            }
        }
    }
}




