//
//  MoreView.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 9/30/23.
//

import SwiftUI

struct MoreView: View {
    @State var isSitterModeEnabled: Bool = false
    @State var notificationsEnabled: Bool = false
    @State private var selectedRole: String = "Pet Parent"
    
    var body: some View {
        VStack {
            TopBarView()
            NavigationView {
                Form {
                    Group {
                        HStack{
                            Spacer()
                            VStack {
                                Spacer()
                                Image("UserProfilePic")
                                    .resizable()
                                    .scaledToFit()
                                    .frame(width:100, height: 100, alignment: .center)
                                Text("Jessica")
                                    .font(.title)
                                Text("hello@jessicasherrington.com")
                                    .font(.subheadline)
                                    .foregroundColor(.gray)
                                Spacer()
                                Button(action: {
                                }) {
                                    Text("Edit Profile")
                                        .font(.headline)
                                        .foregroundColor(.white)
                                        .padding()
                                        .frame(width: 330, height: 47)
                                        .background(CustomColor.myColor)
                                        .cornerRadius(10)
                                }
                                .padding(.bottom)
                            }
                            Spacer()
                        }
                    }
                    
                    Section(content: {
                        HStack {
                            Image(systemName:"pawprint.circle.fill")
                            Toggle(isOn: $isSitterModeEnabled) {
                                Text("Pet Sitter Mode")
                            }
                            .tint(CustomColor.myColor)
                        }
                    })
                    .onChange(of: isSitterModeEnabled) { newValue in
                        selectedRole = newValue ? "Caregiver" : "Pet Parent"
                        UserDefaults.standard.set(selectedRole, forKey: "selectedRole")
                        NavigationHelper.shared.navigateToHomeView(selectedRole: selectedRole)
                    }

                    
                    Section( content: {
                        HStack{
                            Image(systemName:"globe");
                            Text("Language")
                        }
                        HStack{
                            Image(systemName:"exclamationmark.bubble");
                            Toggle(isOn: $notificationsEnabled) {
                                Text("Notifications")
                            }
                            .tint(CustomColor.myColor)
                            
                        }
                        HStack{
                            Image(systemName:"gearshape");
                            Text("Account")
                        }
                        
                    })
                }
            }
            .tint(CustomColor.myColor)

        }
    }
}
struct MoreView_Previews: PreviewProvider {
    static var previews: some View {
        MoreView()
    }
}
