//
//  EditProfileOne.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 10/26/23.
//

import SwiftUI
struct HealthInfo: Identifiable {
    var id = UUID()
    var allergies: String
    var weight: String
    var disabilities: String
    var additionalInfo: String
}

struct Medication: Identifiable {
    var id = UUID()
    var name: String
    var dose: String
    var administrationMethod: String
    var frequency: String
    var specificTimes: String
    var additionalInfo: String
}

struct DietInfo: Identifiable {
    var id = UUID()
    var mealNumber: Int
    var mealTime: Date
    var portionSizes: String
    var additionalInfo: String
}

struct EditProfileOne: View {
    @State private var petName = ""
    @State private var petType = "dog"
    @State private var breed = ""
    @State private var gender = "Male"
    @State private var birthDate = Date()
    @State private var spayedOrNeutered = false
    @State private var microChip = false
    @State private var allergies = ""
    @State private var diet = ""
    @State private var feedingSchedule = ""
    @State private var pottySchedule = ""
    @State private var medications = ""
    @State private var vetName = ""
    @State private var emergencyVet = ""
    @State private var friendlyWithOthers = false
    @State private var friendlyWithKids = true
    @State private var pottyTrained = true
    @State private var favoriteToy = ""
    @State private var knownCommands: [String] = []
    @State private var additionalInfo = ""
    @State private var medicationsList: [Medication] = []
    @State private var healthInfo: HealthInfo = HealthInfo(allergies: "", weight: "", disabilities: "", additionalInfo: "")
    @State private var dietInfo: DietInfo = DietInfo(mealNumber: 1, mealTime: Date(), portionSizes: "", additionalInfo: "")

    @State private var selectedImage: UIImage?
    @State private var isImagePickerPresented = false
    @AppStorage("petProfile") private var petProfileData: Data = Data()

    @Environment(\.presentationMode) var presentationMode
    
    var body: some View {
            Form {
                Section(header: Text("Pet Photo")) {
                    ZStack(alignment: .bottom) {

                        RoundedRectangle(cornerRadius: 10)
                            .fill(Color.gray.opacity(0.3))
                            .frame(height: 200)
                            .overlay(
                                selectedImageView
                            )

                        Button(action: {
                            isImagePickerPresented.toggle()
                        }) {
                            Text(selectedImage != nil ? "Edit Image" : "Add Image")
                                .font(.custom("Inter", size: 17))
                                .frame(width: 100.0, height: 30)
                                .background(Color.white)
                                .foregroundColor(.black)
                                .cornerRadius(8)
                                .padding()
                        }
                    }
                    .sheet(isPresented: $isImagePickerPresented) {
                        ImagePicker(selectedImage: $selectedImage, isImagePickerPresented: $isImagePickerPresented)
                    }
                }
                Section(header: Text("Pet Info")) {
                    HStack {
                        Text("Name:")
                        TextField("", text: $petName)
                    }
                    HStack {
                        Text("Breed:")
                    TextField("", text: $breed)
                }
                        Picker("Gender", selection: $gender) {
                            Text("Male").tag("Male")
                            Text("Female").tag("Female")
                        }
                    Picker("Spayed/Neutered", selection: $spayedOrNeutered){
                        Text("Yes").tag("Yes")
                        Text("No").tag("No")
                    }
                    
                    Picker("Microchipped", selection: $microChip){
                        Text("Yes").tag("Yes")
                        Text("No").tag("No")
                    }
                }
                .tint(CustomColor.myColor)
                
                Section(header: Text("Health")) {
                    DisclosureGroup("Overall Health") {
                        HStack {
                            Text("Weight:")
                            TextField("", text: $healthInfo.weight)
                        }

                            HStack {
                                Text("Allergies:")
                                TextField("", text: $healthInfo.allergies)
                            }
                            VStack {
                                Text("Health Issues:")
                                    .multilineTextAlignment(.leading)
                                    .padding(.trailing, 27.0)
                                TextField("", text: $healthInfo.disabilities)
                            }
                                TextField("Notes", text: $additionalInfo)
                                    .frame(height: 100)
                                    .cornerRadius(8)
                        }
                     

                    DisclosureGroup("Medications") {
                        ForEach(medicationsList.indices, id: \.self) { index in
                            MedicationRow(medication: $medicationsList[index])
                        }
                        .onDelete { indices in
                            medicationsList.remove(atOffsets: indices)
                        }
                        
                        Button(action: {
                            medicationsList.append(Medication(name: "", dose: "", administrationMethod: "", frequency: "", specificTimes: "", additionalInfo: ""))
                        }) {
                            Label("Add Medication", systemImage: "plus.circle.fill")
                        }
                    }

                    DisclosureGroup("Diet") {
                        HStack {
                            Text("Meal Number:")
                            Picker("", selection: $dietInfo.mealNumber) {
                                ForEach(1 ..< 6) { number in
                                    Text("Meal \(number)")
                                }
                            }
                            .pickerStyle(MenuPickerStyle())
                        }

                        HStack {
                            Text("Time:")
                            DatePicker("Time", selection: $dietInfo.mealTime, displayedComponents: .hourAndMinute)
                                .datePickerStyle(WheelDatePickerStyle())
                        }

                        HStack {
                            Text("Portion Sizes:")
                            TextField("Enter portion sizes", text: $dietInfo.portionSizes)
                        }

                        TextField("Notes", text: $dietInfo.additionalInfo)
                            .frame(height: 100)
                            .cornerRadius(8)
                    }
                }
                
                Section {
                    DisclosureGroup ("Personality"){
                        Picker("Friendly with Other Animals", selection: $friendlyWithOthers){
                            Text("Yes").tag("Yes")
                            Text("No").tag("No")
                        }
                        
                        Picker("Friendly with Children", selection: $friendlyWithKids){
                            Text("Yes").tag("Yes")
                            Text("No").tag("No")
                        }
                        
                        Picker("Potty Trained", selection: $pottyTrained){
                            Text("Yes").tag("Yes")
                            Text("No").tag("No")
                        }
                        
                        TextField("Notes", text: $additionalInfo)
                            .frame(height: 100)
                            .cornerRadius(8)
                    }
                }
                .tint(CustomColor.myColor)

                    NavigationLink(destination: ProfileOne()){
                        Section {
                            Text("Save Pet Profile")
                                .foregroundColor(CustomColor.myColor)
                                .multilineTextAlignment(.center)

                        }
                    }
                }
            .accentColor(CustomColor.myColor)
            .navigationTitle("Edit Pet Profile")
            .navigationBarTitleDisplayMode(.inline)
            .navigationBarItems(trailing:
                Button("Cancel") {
                    presentationMode.wrappedValue.dismiss()
                }
            )
        .accentColor(CustomColor.myColor)
    }
    
    private var selectedImageView: some View {
        Group {
            if let image = selectedImage {
                Image(uiImage: image)
                    .resizable()
                    .scaledToFit()
                    .frame(height: 200)
                    .cornerRadius(10)
            } else {
                Text("Profile Photo")
                    .foregroundColor(.white)
            }
        }
    }
}

struct MedicationRow: View {
    @Binding var medication: Medication

    var body: some View {
        VStack(alignment: .leading, spacing: 8) {
            HStack {
                Text("Medication Name:")
                TextField("", text: $medication.name)
            }

            HStack {
                Text("Dose:")
                TextField("How much medication?", text: $medication.dose)
            }

            HStack {
                Text("Administration Method:")
                TextField("Pill, injection, etc.", text: $medication.administrationMethod)
            }

            HStack {
                Text("Frequency:")
                TextField("", text: $medication.frequency)
            }

            HStack {
                Text("Specific Times:")
                TextField("Enter times", text: $medication.specificTimes)
            }

            HStack {
                Text("Notes:")
                TextField("", text: $medication.additionalInfo)
            }
        }
        .padding(EdgeInsets(top: 8, leading: 0, bottom: 8, trailing: 0))
    }
}

struct ImagePicker: UIViewControllerRepresentable {
    @Binding var selectedImage: UIImage?
    @Binding var isImagePickerPresented: Bool

    class Coordinator: NSObject, UINavigationControllerDelegate, UIImagePickerControllerDelegate {
        var parent: ImagePicker

        init(parent: ImagePicker) {
            self.parent = parent
        }

        func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [UIImagePickerController.InfoKey: Any]) {
            if let uiImage = info[.originalImage] as? UIImage {
                parent.selectedImage = uiImage
            }

            parent.isImagePickerPresented = false
        }

        func imagePickerControllerDidCancel(_ picker: UIImagePickerController) {
            parent.isImagePickerPresented = false
        }
    }

    func makeCoordinator() -> Coordinator {
        return Coordinator(parent: self)
    }

    func makeUIViewController(context: UIViewControllerRepresentableContext<ImagePicker>) -> UIImagePickerController {
        let imagePicker = UIImagePickerController()
        imagePicker.delegate = context.coordinator
        imagePicker.sourceType = .photoLibrary
        imagePicker.allowsEditing = true
        return imagePicker
    }

    func updateUIViewController(_ uiViewController: UIImagePickerController, context: UIViewControllerRepresentableContext<ImagePicker>) {
    }
}

struct EditProfileOne_Previews: PreviewProvider {
    static var previews: some View {
        EditProfileOne()
    }
}
