//
//  LocationTrackingView.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 11/5/23.
//
import SwiftUI
import CoreLocation
import MapKit

struct LocationTrackingView: View {
    @ObservedObject var locationViewModel = LocationViewModel()
    @State private var petAnnotations: [PetAnnotation] = []

    var body: some View {
        VStack {
            MapView(userLocation: $locationViewModel.userLocationCoordinate, petAnnotations: $petAnnotations)
                .onAppear {
                    locationViewModel.startUpdatingLocation()

                    locationViewModel.pets = [
                        Pet(name: "Burnley", profilePhoto: "Burnley1", location: CLLocationCoordinate2D(latitude: 33.75166, longitude: -84.32370), isTrackingEnabled: true)                   ]

                    updatePetAnnotations()
                }
                .onDisappear {
                    locationViewModel.stopUpdatingLocation()
                }
        }
        .accentColor(CustomColor.myColor)
        .ignoresSafeArea()
    }

    private func updatePetAnnotations() {
        petAnnotations = locationViewModel.pets.map { pet in
            if let petImage = UIImage(named: pet.profilePhoto) {
                let circularThumbnail = petImage.circularThumbnail(with: CGSize(width: 50, height: 50))
                return PetAnnotation(
                    coordinate: pet.location ?? CLLocationCoordinate2D(latitude: 0, longitude: 0),
                    title: pet.name,
                    subtitle: nil,
                    image: circularThumbnail
                )
            } else {
                return PetAnnotation(
                    coordinate: CLLocationCoordinate2D(latitude: 0, longitude: 0),
                    title: pet.name,
                    subtitle: nil,
                    image: nil
                )
            }
        }
    }
}



struct LocationTrackingView_Previews: PreviewProvider {
    static var previews: some View {
        LocationTrackingView()
    }
}


