//
//  MapView.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 11/5/23.
//

import SwiftUI
import MapKit
import UIKit

extension UIImage {
    func circularThumbnail(with size: CGSize) -> UIImage? {
        UIGraphicsBeginImageContextWithOptions(size, false, 0.0)
        let bounds = CGRect(x: 0, y: 0, width: size.width, height: size.height)
        UIBezierPath(roundedRect: bounds, cornerRadius: size.width / 2).addClip()
        draw(in: bounds)
        let result = UIGraphicsGetImageFromCurrentImageContext()
        UIGraphicsEndImageContext()
        return result
    }
}

struct MapView: UIViewRepresentable {
    @Binding var userLocation: CLLocationCoordinate2D?
    @Binding var petAnnotations: [PetAnnotation]

    func makeUIView(context: Context) -> MKMapView {
        let mapView = MKMapView()
        mapView.delegate = context.coordinator
        return mapView
    }

    func updateUIView(_ uiView: MKMapView, context: Context) {
        uiView.removeAnnotations(uiView.annotations)

        if let userCoordinate = userLocation {
            let userAnnotation = MKPointAnnotation()
            userAnnotation.coordinate = userCoordinate
            userAnnotation.title = "You"
            uiView.addAnnotation(userAnnotation)
        }

        for petAnnotation in petAnnotations {
            uiView.addAnnotation(petAnnotation)
        }

        if let coordinate = userLocation {
            let span = MKCoordinateSpan(latitudeDelta: 0.005, longitudeDelta: 0.005)
            let region = MKCoordinateRegion(center: coordinate, span: span)
            uiView.setRegion(region, animated: true)
        }
    }


    func makeCoordinator() -> Coordinator {
        return Coordinator(self)
    }

    class Coordinator: NSObject, MKMapViewDelegate {
        var parent: MapView

        init(_ parent: MapView) {
            self.parent = parent
        }

        func mapView(_ mapView: MKMapView, viewFor annotation: MKAnnotation) -> MKAnnotationView? {
            guard let petAnnotation = annotation as? PetAnnotation else {
                return nil
            }

            let annotationView = MKAnnotationView(annotation: petAnnotation, reuseIdentifier: "petAnnotation")
            annotationView.image = petAnnotation.image
            return annotationView
        }
    }
}



