//
//  PetOne.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 10/7/23.
//

import SwiftUI
import Popovers


struct PetOne: View {
    @State private var isPopover1Presented = false
    @State private var isPopover2Presented = false
    @State private var isPopover3Presented = false
    
    var body: some View {
        ScrollView {
            VStack(spacing: 20) {
                ZStack{
                    Image("Burnley1")
                        .resizable()
                        .aspectRatio(contentMode: .fill)
                        .padding(.top, 150.0)
                        .frame(minWidth: 0, maxWidth: .infinity)
                        .frame(height: 220)
                        .ignoresSafeArea()
                        .clipShape(RoundedRectangle(cornerRadius: 10))
                        .shadow(radius: 2)
                }

                
                
                VStack(alignment: .leading, spacing: 10) {
                    Text("Burnley")
                        .font(.custom("Poppins-Bold", size: 30))
                    
                    Text("7yrs, 5mos")
                        .font(.subheadline)
                        .foregroundColor(.gray)
                    
                    Text("Boston Terrier/French Bulldog Mix")
                        .font(.subheadline)
                        .foregroundColor(.gray)
                    
                    HStack {
                        Text("Male")
                            .font(.subheadline)
                            .foregroundColor(.gray)
                    }
                }
                .padding(.trailing, 100.0)
                
                ZStack {
                    RoundedRectangle(cornerRadius: 10)
                        .fill(Color.gray.opacity(0.1))
                        .frame(height: 160)
                        .shadow(radius: 2)
                    ZStack {
                        RoundedRectangle(cornerRadius: 4)
                            .fill(.white)
                            .frame(width: 150.0, height: 35)
                        RoundedRectangle(cornerRadius: 4)
                            .fill(CustomColor.myColor)
                            .frame(width: 140.0, height: 26)
                            .shadow(radius: 1)
                        Text("Important")
                            .font(.subheadline)
                            .fontWeight(.bold)
                            .foregroundColor(Color.white)
                    }
                        .offset(x: -100, y: -76)
                    ZStack {
                        Circle()
                            .fill(.white)
                            .frame(height: 70)
                        Circle()
                            .fill(CustomColor.myColor)
                            .frame(height: 60)
                            .shadow(radius: 1)
                        Image(systemName: "exclamationmark.circle")
                            .resizable()
                         .frame(width: 40, height: 40)
                            .foregroundColor(.white)
                    }
                        .offset(x: 146, y: -92)
                HStack(spacing: 20) {
                    VStack {
                        Image("OtherDogs")
                            .resizable()
                            .aspectRatio(contentMode: .fit)
                            .padding()
                            .foregroundColor(CustomColor.myColor)
                    }
                    .frame(width: 90, height: 90)
                    .background(Color.white)
                    .cornerRadius(10)
                    .shadow(radius: 3)
                    .onTapGesture {
                        isPopover1Presented.toggle()
                    }
                    .popover(
                        present: $isPopover1Presented,
                        attributes: {
                            $0.position = .absolute(
                                originAnchor: .bottomLeft,
                                popoverAnchor: .topLeft
                            )
                        }
                    )
                    {
                        Text("I'm not friendly with other pets")
                            .font(.custom("Poppins-Bold", size: 17))
                            .padding()
                            .foregroundColor(.white)
                            .background(CustomColor.myColor)
                            .cornerRadius(16)
                    }
                    
                    
                    VStack {
                        Image("Kids")
                            .resizable()
                            .aspectRatio(contentMode: .fit)
                            .padding()
                            .foregroundColor(CustomColor.myColor)
                    }
                    .frame(width: 90, height: 90)
                    .background(Color.white)
                    .cornerRadius(10)
                    .shadow(radius: 3)
                    .onTapGesture {
                        isPopover2Presented.toggle()
                    }
                    .popover(
                        present: $isPopover2Presented,
                        attributes: {
                            $0.position = .absolute(
                                originAnchor: .bottom,
                                popoverAnchor: .top
                            )
                        }
                    ) {
                        Text("I am friendly with children")
                            .font(.custom("Poppins-Bold", size: 17))
                            .padding()
                            .foregroundColor(.white)
                            .background(CustomColor.myColor)
                            .cornerRadius(16)
                    }
                    VStack {
                        Image("Meds")
                            .resizable()
                            .aspectRatio(contentMode: .fit)
                            .padding()
                            .foregroundColor(CustomColor.myColor)
                    }
                    .frame(width: 90, height: 90)
                    .background(Color.white)
                    .cornerRadius(10)
                    .shadow(radius: 3)
                    .onTapGesture {
                        isPopover3Presented.toggle()
                    }
                    .popover(
                        present: $isPopover3Presented,
                        attributes: {
                            $0.position = .absolute(
                                originAnchor: .bottomRight,
                                popoverAnchor: .topRight
                            )
                        }
                    ) {
                        Text("I require medication")
                            .font(.custom("Poppins-Bold", size: 17))
                            .padding()
                            .foregroundColor(.white)
                            .background(CustomColor.myColor)
                            .cornerRadius(16)
                    }
                }
                .padding(.horizontal)
                .padding(.top)
                }
                .padding(.vertical)
                VStack(spacing: 24) {
                    ZStack {
                        RoundedRectangle(cornerRadius: 10)
                            .fill(.white)
                            .frame(height: 200)
                            .shadow(radius: 2)
                        VStack(alignment: .leading) {
                            HStack {
                                Image("Food")
                                    .resizable()
                                    .frame(width: 42.0, height: 40.0)
                                Text("Meals")
                                    .font(.custom("Poppins-Bold", size: 20))
                                    .padding(.leading, 5.0)
                            }
                            .padding(.trailing)
                            Divider()
                            Text("Give one scoop of kibble for breakfast, lunch, and dinner.")
                                .multilineTextAlignment(.leading)
                            HStack(spacing: 30) {
                                HStack {
                                    Image("Clock")
                                        .resizable()
                                        .frame(width: 20.0, height: 20.0)
                                    Text("Daily")
                                }
                                HStack {
                                    Image("Clock")
                                        .resizable()
                                        .frame(width: 20.0, height: 20.0)
                                    Text("9AM")
                                }
                                HStack {
                                    Image("Clock")
                                        .resizable()
                                        .frame(width: 20.0, height: 20.0)
                                    Text("9PM")
                                }
                            
                            }
                            .padding(.top)                     }
                        .padding()
                        .frame(width: 340.0, height: 200)
                        
                    }
                    ZStack {
                        RoundedRectangle(cornerRadius: 10)
                            .fill(.white)
                            .frame(height: 230)
                            .shadow(radius: 2)
                        VStack(alignment: .leading) {
                            HStack {
                                Image("Health")
                                    .resizable()
                                    .frame(width: 40.0, height: 40.0)
                                Text("Health")
                                    .font(.custom("Poppins-Bold", size: 20))
                                    .padding(.leading, 5.0)
                            }
                            .padding(.trailing)
                            Divider()
                            HStack(alignment: .center) {
                                    Image("Caution")
                                        .resizable()
                                        .frame(width: 24.0, height: 24.0)
                                    Text("I have epilepsy. This means that I am prone to seizures.")
                                        .multilineTextAlignment(.leading)
                            }
                                .padding(.top)
                            HStack(alignment: .center) {
                                NavigationLink(destination: Prescriptions()){
                                    HStack(alignment: .center) {
                                Image("Pills")
                                .resizable()
                                .frame(width: 24.0, height: 24.0)
                                Text("I take medications")
                                .multilineTextAlignment(.leading)
                                Image(systemName: "chevron.right")
                                    .font(.custom("Inter", size: 17)) .foregroundColor(CustomColor.myColor)
                                    }
                                }
                            }
                            .padding(.top)
                            Spacer()
                        }
                        .padding()
                        .frame(width: 340.0, height: 220)
                        
                        
                    }
                    ZStack {
                        RoundedRectangle(cornerRadius: 10)
                            .fill(.white)
                            .frame(height: 275)
                            .shadow(radius: 2)
                        VStack(alignment: .leading) {
                            HStack {
                                Image("SleepyCat")
                                    .resizable()
                                    .frame(width: 40.0, height: 40.0)
                                Text("Personality")
                                    .font(.custom("Poppins-Bold", size: 20))
                                    .padding(.leading, 5.0)
                            }
                            .padding(.trailing)
                            Divider()
                            HStack(alignment: .center) {
                                    Image("Caution")
                                        .resizable()
                                        .frame(width: 24.0, height: 24.0)
                                    Text("I do not get along with other dogs.")
                                        .multilineTextAlignment(.leading)
                            }
                                .padding(.top)
                       
                        HStack(alignment: .center) {
                            Image("Kids")
                                .resizable()
                                .frame(width: 24.0, height: 24.0)
                            Text("I am great with children.")
                                .multilineTextAlignment(.leading)
                            }
                            .padding(.top)
                            HStack(alignment: .center) {
                                    Image("Ball")
                                        .resizable()
                                        .frame(width: 24.0, height: 24.0)
                                    Text("I have a lot of energy and I love playing fetch.")
                                        .multilineTextAlignment(.leading)
                            }
                                .padding(.top)                        }
                        .padding()
                        .frame(width: 340.0, height: 260)
                    }

                    Spacer()
                }
                    Text("Upcoming")
                        .font(.custom("Poppins-Bold", size: 20))
                        .multilineTextAlignment(.leading)
                        .padding(.trailing, 220.0)
                VStack(spacing: 24) {
                    ZStack {
                        RoundedRectangle(cornerRadius: 10)
                            .fill(.white)
                            .frame(height: 200)
                            .shadow(radius: 2)
                        VStack(alignment: .leading) {
                            HStack {
                                Image("Pills")
                                    .resizable()
                                    .frame(width: 40.0, height: 40.0)
                                Text("Phenobarbital")
                                    .font(.custom("Poppins-Bold", size: 18))
                            }
                            .padding(.trailing)
                            
                            Text("Give one tablet orally twice every day for epilepsy treatment.")
                                .multilineTextAlignment(.leading)
                            HStack(spacing: 30) {
                                HStack {
                                    Image("Calendar")
                                        .resizable()
                                        .frame(width: 20.0, height: 20.0)
                                    Text("Daily")
                                }
                                HStack {
                                    Image("Clock")
                                        .resizable()
                                        .frame(width: 20.0, height: 20.0)
                                    Text("9AM")
                                }
                                HStack {
                                    Image("Clock")
                                        .resizable()
                                        .frame(width: 20.0, height: 20.0)
                                    Text("9PM")
                                }
                            
                            }
                            .padding(.top)                     }
                        .padding()
                        .frame(width: 340.0, height: 200)
                        
                    }
                    ZStack {
                        RoundedRectangle(cornerRadius: 10)
                            .fill(.white)
                            .frame(height: 200)
                            .shadow(radius: 2)
                        VStack(alignment: .leading) {
                            HStack {
                                Image("Pills")
                                    .resizable()
                                    .frame(width: 40.0, height: 40.0)
                                Text("Keppra")
                                    .font(.custom("Poppins-Bold", size: 18))
                            }
                            .padding(.trailing)
                            Text("Give one tablet orally twice every day for epilepsy treatment.")
                                .multilineTextAlignment(.leading)
                            HStack(spacing: 30) {
                                HStack {
                                    Image("Calendar")
                                        .resizable()
                                        .frame(width: 20.0, height: 20.0)
                                    Text("Daily")
                                }
                                HStack{
                                    Image("Clock")
                                        .resizable()
                                        .frame(width: 20.0, height: 20.0)
                                    Text("9AM")
                                }
                                HStack {
                                    Image("Clock")
                                        .resizable()
                                        .frame(width: 20.0, height: 20.0)
                                    Text("9PM")
                                }
                            }
                            .padding(.top)                    }
                        .padding()
                        .frame(width: 340.0, height: 200)
                        
                        
                    }
                    Divider()
                        .padding(.vertical)
                    ZStack {
                        RoundedRectangle(cornerRadius: 10)
                            .fill(.white)
                            .frame(height: 260)
                            .shadow(radius: 2)
                        VStack(alignment: .leading) {
                            HStack {
                                Image("Health2")
                                    .resizable()
                                    .frame(width: 40.0, height: 40.0)
                                Text("My Veterinarian")
                                    .font(.custom("Poppins-Bold", size: 20))
                                    .padding(.leading, 5.0)
                            }
                            .padding(.trailing)
                            Divider()
                         
                            Text("Dr. Kaya Bryant")
                                .font(.custom("Poppins-Bold", size: 18))
                                .padding([.top, .leading])
                            Text("The Village Vets Decatur-Ponce")
                                .padding(.leading)
                            Text("245 W. Ponce De Leon Ave., Ste D")
                                .font(.subheadline)
                                .foregroundColor(Color.gray)
                                .padding(.leading)
                            Text("Decatur, GA 30030")
                                .font(.subheadline)
                                .foregroundColor(Color.gray)
                                .padding(.leading)
                            ZStack{
                                RoundedRectangle(cornerRadius: 10)
                                    .fill(CustomColor.myColor)
                                    .frame(width: 260.0, height: 34)
                                Text("Call Now")
                                    .fontWeight(.bold)
                                    .foregroundColor(Color.white)
                            }
                            .padding([.top, .leading])
                        }
                        .padding()
                        .frame(width: 340.0, height: 240)
                    }
                }
                
            }
            .padding()
            .tint(CustomColor.myColor)
        }
    }
}

struct PetOne_Previews: PreviewProvider {
    static var previews: some View {
        PetOne()
    }
}



