//
//  ToDoListView.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 9/30/23.
//

import SwiftUI

struct Task: Identifiable {
    var id = UUID()
    var title: String
    var isCompleted: Bool = false
}

struct ToDoListView: View {
    @State private var tasks: [Task] = [
        Task(title: "Pick up Burnley @8AM"),
        Task(title: "Burnley's morning pills"),
        Task(title: "Burnley's evening pills")]
    @State private var newTaskTitle: String = ""

    var body: some View {
        NavigationView {
            VStack {
                List {
                    ForEach(tasks) { task in
                        TaskRowView(task: task, toggleCompletion: {
                            toggleCompletion(for: task)
                        })
                    }
                    .onDelete(perform: deleteTasks)
                }
                .listStyle(InsetGroupedListStyle())
                .scrollContentBackground(.hidden)
                .background(.white)

                HStack {
                    TextField("New Task", text: $newTaskTitle)
                        .textFieldStyle(RoundedBorderTextFieldStyle())
                        .padding(.horizontal)

                    Button(action: {
                        addTask()
                    }) {
                        Image(systemName: "plus.circle.fill")
                            .resizable()
                            .frame(width: 30, height: 30)
                            .foregroundColor(CustomColor.myColor)
                    }
                    .padding(.trailing)
                }
                .padding(.top)
                .background(Color.white)
            }
            .navigationBarItems(trailing: EditButton())
            .background(Color.white)
        }
        .tint(CustomColor.myColor)
        .background(Color.white)
    }

    private func addTask() {
        guard !newTaskTitle.isEmpty else { return }
        let newTask = Task(title: newTaskTitle)
        tasks.append(newTask)
        newTaskTitle = ""
    }

    private func toggleCompletion(for task: Task) {
        if let index = tasks.firstIndex(where: { $0.id == task.id }) {
            tasks[index].isCompleted.toggle()
        }
    }

    private func deleteTasks(offsets: IndexSet) {
        tasks.remove(atOffsets: offsets)
    }
}

struct TaskRowView: View {
    var task: Task
    var toggleCompletion: () -> Void

    var body: some View {
        HStack(alignment: .center) {
            Button(action: toggleCompletion) {
                Image(systemName: task.isCompleted ? "checkmark.circle.fill" : "circle")
                    .resizable()
                    .frame(width: 20, height: 20)
                    .foregroundColor(task.isCompleted ? CustomColor.myColor : .gray)
            }

            Text(task.title)
                .strikethrough(task.isCompleted)
                .foregroundColor(task.isCompleted ? .gray : .black)

            Spacer()
        }
    }
}

struct ToDoListView_Previews: PreviewProvider {
    static var previews: some View {
        ToDoListView()
    }
}




